@@ -109,8 +109,26 @@ class Controller():
             rt["user"]=rtUser
             rt["author"]=rtUser
             status["retweeted_status"]=rt
+            
+        if status["status"]!=None:
+            Id=status["status"]
+            #print "_construct_a_status, comment status id :" + str(Id) + " status ID:" + str(status["id"])
+            comment_status=self.dao.get_status_by_account_and_id(account, Id)
+            self._construct_a_status(account,comment_status)
+            status["status"]=comment_status
+            #print str(status["status"]["id"]) + " " + status["status"]["text"]
+            
+        if status["reply_comment"]!=None:
+            reply_comment_id=status["reply_comment"]
+            #print "_construct_a_status, reply_comment id :" + str(reply_comment_id) + " status ID:" + str(status["id"])
+            reply_comment=self.dao.get_status_by_account_and_id(account, reply_comment_id)
+            self._construct_a_status(account,reply_comment)
+            status["reply_comment"]=reply_comment
+            #print str(status["reply_comment"]["id"]) + " " + status["reply_comment"]["text"]
+            
 
     def save_statuses(self,account,statuses,timelineType):
+        #print "save_statuses"
         if statuses!=None:
             for status in statuses:
                 if timelineType==Utils.TIMELINE_TYPE_FRIENDS:
@@ -129,7 +147,7 @@ class Controller():
                 self.save_a_status(account,status)
 
     def save_a_status(self,account,status):
-        
+        #print "save_a_status :"+status["text"]+str(status["id"])
         self.logger.debug("save_a_status")
         rt=status["retweeted_status"]
         if rt!=None:
@@ -143,6 +161,28 @@ class Controller():
             rt["user"]=rtUser
             rt["author"]=rtUser
             status["retweeted_status"]=rt["id"]
+
+        try:
+#for commented status
+            s=status["status"]
+            if s!=None:
+                self.save_a_status(account,s)
+                status["status"]=s["id"]
+                #print "sid:" + str(s["id"])
+        except KeyError:
+            s=None
+            #print "save_a_status commented:"+status["text"]
+#for reply_comment status
+        try:
+            reply_comment=status["reply_comment"]
+            if reply_comment!=None:
+                self.save_a_status(account,reply_comment)
+                status["reply_comment"]=reply_comment["id"]
+                #print "reply_comment id:" + str(reply_comment["id"])
+        except KeyError:
+            reply_comment=None
+            #print "save_a_status reply_comment:"+status["text"]
+            
         user=status["user"]
         if user!=None:
             self.save_a_user(user)
@@ -150,12 +190,19 @@ class Controller():
             status["author"]=user["id"]
         r=self.dao.get_a_status_by_id(account, status["id"])
         if r==None:
+            #print "save_a_status :"+status["text"]
             status=self.dao.add_a_status(status)
             #print "save_status"
             #print status
+        else:
+            print "r status_id :" + str(r["status_id"])
+            status["status_id"] = r["status_id"]
+
         status["user"]=user
         status["author"]=user
         status["retweeted_status"]=rt
+        status["status"]=s
+        status["reply_comment"]=reply_comment
 
     def del_status_by_id(self,account,id):
         self.dao.del_status_by_id(account,id)
